**********************************
:mod:`gruvi` -- Base functionality
**********************************

.. module:: gruvi

.. class:: gruvi.Error

   Base class for all exceptions in Gruvi. This is an alias of
   :exc:`pyuv.UVError`.

.. autoclass:: gruvi.Timeout

.. autoclass:: gruvi.Cancelled
